package com.hongyegroup.cpt_main.ui

import android.os.Bundle
import android.view.View
import android.widget.ImageView
import com.guadou.cs_cptservices.base.fragment.YYBaseVDBLoadingFragment
import com.guadou.cs_cptservices.interfaces.IFragmentRefresh
import com.guadou.lib_baselib.bean.DataBindingConfig
import com.guadou.lib_baselib.engine.extLoad
import com.guadou.lib_baselib.engine.toast
import com.guadou.lib_baselib.ext.bindData
import com.guadou.lib_baselib.ext.click
import com.guadou.lib_baselib.ext.horizontal
import com.guadou.lib_baselib.ext.vertical
import com.guadou.lib_baselib.utils.CommUtils
import com.guadou.lib_baselib.view.gloading.GLoadingTitleStatus
import com.guadou.lib_baselib.view.gloading.Gloading
import com.guadou.lib_baselib.view.gloading.GloadingGlobalAdapter
import com.hongyegroup.cpt_main.BR
import com.hongyegroup.cpt_main.R
import com.hongyegroup.cpt_main.databinding.FragmentHomeBinding
import com.hongyegroup.cpt_main.mvvm.HomeViewModel
import com.scwang.smart.refresh.layout.api.RefreshLayout
import com.scwang.smart.refresh.layout.listener.OnRefreshListener

/**
 * 首页列表
 */
class HomeFragment : YYBaseVDBLoadingFragment<HomeViewModel, FragmentHomeBinding>(), IFragmentRefresh,
    OnRefreshListener {

    override fun getDataBindingConfig(): DataBindingConfig {
        return DataBindingConfig(R.layout.fragment_home, BR.viewModel, mViewModel)
            .addBindingParams(BR.click, ClickProxy())
    }

    //重新生成GLoading对象-跳动动画
    override fun generateGLoading(view: View): Gloading.Holder {
        return Gloading.from(GloadingGlobalAdapter())
            .wrap(view, GLoadingTitleStatus(true, true, true))
            .withRetry { onGoadingRetry() }
    }

    override fun startObserve() {
    }

    override fun init(savedInstanceState: Bundle?) {

        initData()
        initListener()
    }

    private fun initData() {
        showStateLoading()

        //获取首页的数据
        //requestHomeData()

        CommUtils.getHandler().postDelayed({
            showStateSuccess()
            popopData()
            mBinding.refreshLayout.finishRefresh()
        }, 1500)
    }


    override fun onGoadingRetry() {
        initData()
    }

    private fun initListener() {
        mBinding.refreshLayout.setEnableNestedScroll(true)
        mBinding.refreshLayout.setEnableLoadMore(false)
        mBinding.refreshLayout.setEnableRefresh(true)
        mBinding.refreshLayout.setOnRefreshListener(this)
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        initData()

        CommUtils.getHandler().postDelayed({
            popopData()
            mBinding.refreshLayout.finishRefresh()
        }, 1500)
    }

    private fun popopData() {

        val hotJobs = listOf("1", "2", "3", "4", "5")
        val cityJobs = listOf("1", "2", "3", "4")
        val areaJobs = listOf("1", "2", "3", "4", "5", "6")
        val jobTips = listOf("1", "2", "3", "4")

        mBinding.rvHotJob.horizontal()
            .bindData(hotJobs, R.layout.item_home_part_time_job) { holder, t, _ ->

                holder.getView<ImageView>(R.id.iv_job_image).extLoad(
                    "http://malaysia-yyjobs-admin-dev.guabean.com/storage/202206/09/9NdPaX0fB66dFc4SMuR2kIqLDiJcVGjTW6vZ9hUu-690x410.png",
                    R.drawable.placeholder_img_top_round_job, isCenterCrop = true, topRoundRadius = 5
                )

                holder.itemView.click {
                    toast("点击进入工作详情")
                }
            }

        mBinding.rvCityJob.horizontal()
            .bindData(cityJobs, R.layout.item_home_part_time_job) { holder, t, _ ->

                holder.getView<ImageView>(R.id.iv_job_image).extLoad(
                    "http://malaysia-yyjobs-admin-dev.guabean.com/storage/202206/09/9NdPaX0fB66dFc4SMuR2kIqLDiJcVGjTW6vZ9hUu-690x410.png",
                    R.drawable.placeholder_img_top_round_job, isCenterCrop = true, topRoundRadius = 5
                )

                holder.itemView.click {
                    toast("点击进入工作详情")
                }
            }

        mBinding.rvAreaJob.horizontal()
            .bindData(areaJobs, R.layout.item_home_part_time_job) { holder, t, _ ->

                holder.getView<ImageView>(R.id.iv_job_image).extLoad(
                    "http://malaysia-yyjobs-admin-dev.guabean.com/storage/202206/09/9NdPaX0fB66dFc4SMuR2kIqLDiJcVGjTW6vZ9hUu-690x410.png",
                    R.drawable.placeholder_img_top_round_job, isCenterCrop = true, topRoundRadius = 5
                )

                holder.itemView.click {
                    toast("点击进入工作详情")
                }
            }

        mBinding.rvJobTips.vertical(2)
            .bindData(jobTips, R.layout.item_home_job_tips) { holder, t, _ ->

                holder.getView<ImageView>(R.id.iv_top_img).extLoad(
                    "http://malaysia-yyjobs-admin-dev.guabean.com/storage/202206/09/9NdPaX0fB66dFc4SMuR2kIqLDiJcVGjTW6vZ9hUu-690x410.png",
                    R.drawable.placeholder_img_top_round_job, isCenterCrop = true, topRoundRadius = 5
                )

                holder.itemView.click {
                    toast("点击进入公告板详情")
                }
            }
    }

    override fun scrollTopRefresh() {
        mBinding.scrollView.smoothScrollTo(0, 0)
        mBinding.refreshLayout.autoRefresh()
    }

    /**
     * DataBinding事件处理
     */
    inner class ClickProxy {

        fun gotoWalletPage() {
            toast("去钱包页面")
        }

        fun gotoRewardsPage() {
            toast("去奖励页面")
        }

        fun gotoParttimePage() {
            toast("去兼职页面")
        }

        fun gotoBulletinBoardPage() {
            toast("去公告板页面")
        }
    }


}